interface APIOptions {
    serverUrl: string;
    cookiePath: string;
    enterprise: boolean;
}
declare type nodeFetchType = (url: RequestInfo, init?: RequestInit | undefined) => Promise<Response>;
export declare enum ExportType {
    PDF = 0,
    SLIDE = 1,
    MD = 2,
    HTML = 3
}
export declare type HistoryItem = {
    id: string;
    text: string;
    time: number | string;
    tags: string[];
};
export declare type NewNoteOption = {
    team: string;
};
/**
 * codimd API Client
 */
declare class API {
    readonly serverUrl: string;
    readonly enterprise: boolean;
    private readonly _fetch;
    constructor(config?: Partial<APIOptions>);
    login(email: string, password: string): Promise<void>;
    loginLdap(username: string, password: string): Promise<void>;
    logout(): Promise<boolean>;
    isLogin(): Promise<boolean>;
    getMe(): Promise<any>;
    getHistory(): Promise<{
        history: HistoryItem[];
    }>;
    newNote(body: string, options?: NewNoteOption): Promise<string>;
    listNotes(): Promise<any>;
    listTeamNotes(teamPath: string): Promise<any>;
    private exportRes;
    exportString(noteId: string, type: ExportType): Promise<string>;
    exportStream(noteId: string, type: ExportType): Promise<ReadableStream<Uint8Array> | null>;
    getTeams(): Promise<any>;
    get fetch(): nodeFetchType;
    get domain(): string | null;
    get defaultFetchOptions(): {
        headers: {
            'User-Agent': string;
        };
    };
    private wrapHeaders;
    private loadCSRFToken;
}
export default API;
